﻿using System;
using System.IO;
using System.Windows;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace ThinkGeoChangeModeProblem
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
        public enum InteractionMode { Normal, Select, Measure, Draw }
        private void Open_Click(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.Meter;

            Microsoft.Win32.OpenFileDialog dlg = new Microsoft.Win32.OpenFileDialog();
            dlg.FileName = "";
            dlg.DefaultExt = ".shp";
            dlg.Filter =
                "Shape Files (*.shp)|*.shp";

            Nullable<bool> result = dlg.ShowDialog();
            if (result == true)
            {
                string FileNameWithouExtension = Path.GetFileNameWithoutExtension(dlg.FileName);

                ShapeFileFeatureLayer shapeFileLayer = new ShapeFileFeatureLayer(dlg.FileName, ShapeFileReadWriteMode.ReadOnly);
                shapeFileLayer.RequireIndex = true;
                ((ShapeFileFeatureSource)shapeFileLayer.FeatureSource).StreamLoading += new EventHandler<StreamLoadingEventArgs>(StreamLoading);

                shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
                shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Equator1;
                shapeFileLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.City2;
                shapeFileLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                LayerOverlay overlay = new LayerOverlay();

                overlay.Layers.Add(FileNameWithouExtension, shapeFileLayer);
                wpfMap1.Overlays.Add(FileNameWithouExtension, overlay);

                shapeFileLayer.Open();
                wpfMap1.CurrentExtent = shapeFileLayer.GetBoundingBox();
                shapeFileLayer.Close();

                wpfMap1.Refresh();
            }
        }
        private static void StreamLoading(object sender, StreamLoadingEventArgs e)
        {
            try
            {
                string fileName = System.IO.Path.GetFileName(e.AlternateStreamName);
                string Directory = System.IO.Path.GetDirectoryName(e.AlternateStreamName);

                if (File.Exists(Directory + @"\\" + fileName)) e.AlternateStream = new FileStream(Directory + @"\\" + fileName, e.FileMode, e.FileAccess);
                else e.AlternateStream = null;
            }
            catch
            {
            }
        }

        private void DrawMode_Click(object sender, RoutedEventArgs e)
        {
            wpfMap1.TrackOverlay = new TrackInteractiveOverlay();
            wpfMap1.TrackOverlay.TrackMode = TrackMode.Rectangle;
            wpfMap1.Refresh(wpfMap1.TrackOverlay);
        }

        private void DrawModeWithRefresh_Click(object sender, RoutedEventArgs e)
        {
            wpfMap1.TrackOverlay = new TrackInteractiveOverlay();
            wpfMap1.TrackOverlay.TrackMode = TrackMode.Rectangle;
            wpfMap1.Refresh();
        }
    }
}